package dev.fyloz.colorrecipesexplorer.config

import dev.fyloz.colorrecipesexplorer.model.ConfigurationType
import dev.fyloz.colorrecipesexplorer.model.configuration
import org.springframework.context.annotation.Bean
import org.springframework.context.annotation.Configuration
import java.io.File
import java.io.FileInputStream
import java.io.FileOutputStream
import java.time.LocalDateTime
import java.util.*

@Configuration
class ConfigurationsInitializer {
    @Bean
    fun fileConfiguration() = FileConfiguration()
}

const val FILE_CONFIGURATION_PATH = "config.properties"
const val FILE_CONFIGURATION_COMMENT = "---Color Recipes Explorer configuration---"

class FileConfiguration {
    val properties = Properties().apply {
        with(File(FILE_CONFIGURATION_PATH)) {
            if (!this.exists()) this.createNewFile()
            FileInputStream(this).use {
                this@apply.load(it)
            }
        }
    }

    fun get(type: ConfigurationType) =
        if (properties.containsKey(type.key))
            configuration(
                type,
                properties[type.key] as String,
                LocalDateTime.parse(properties[configurationLastUpdateKey(type.key)] as String)
            )
        else null

    fun set(type: ConfigurationType, content: String) {
        properties[type.key] = content
        properties[configurationLastUpdateKey(type.key)] = LocalDateTime.now().toString()
        save()
    }

    fun save() {
        FileOutputStream(FILE_CONFIGURATION_PATH).use {
            properties.store(it, FILE_CONFIGURATION_COMMENT)
        }
    }

    private fun configurationLastUpdateKey(key: String) = "$key.last-updated"
}
