package dev.fyloz.colorrecipesexplorer.rest

import dev.fyloz.colorrecipesexplorer.config.annotations.PreAuthorizeViewCatalog
import dev.fyloz.colorrecipesexplorer.model.Company
import dev.fyloz.colorrecipesexplorer.model.CompanySaveDto
import dev.fyloz.colorrecipesexplorer.model.CompanyUpdateDto
import dev.fyloz.colorrecipesexplorer.service.CompanyService
import org.springframework.context.annotation.Profile
import org.springframework.security.access.prepost.PreAuthorize
import org.springframework.web.bind.annotation.*
import javax.validation.Valid

private const val COMPANY_CONTROLLER_PATH = "api/company"

@RestController
@RequestMapping(COMPANY_CONTROLLER_PATH)
@Profile("!emergency")
@PreAuthorizeViewCatalog
class CompanyController(private val companyService: CompanyService) {
    @GetMapping
    fun getAll() =
      ok(companyService.getAllForOutput())

    @GetMapping("{id}")
    fun getById(@PathVariable id: Long) =
      ok(companyService.getByIdForOutput(id))

    @PostMapping
    @PreAuthorize("hasAuthority('EDIT_COMPANIES')")
    fun save(@Valid @RequestBody company: CompanySaveDto) =
      created<Company>(COMPANY_CONTROLLER_PATH) {
          companyService.save(company)
      }

    @PutMapping
    @PreAuthorize("hasAuthority('EDIT_COMPANIES')")
    fun update(@Valid @RequestBody company: CompanyUpdateDto) =
      noContent {
          companyService.update(company)
      }

    @DeleteMapping("{id}")
    @PreAuthorize("hasAuthority('EDIT_COMPANIES')")
    fun deleteById(@PathVariable id: Long) =
      noContent {
          companyService.deleteById(id)
      }
}
